# AutoClick 📱
파이썬용 오토클릭 라이브러리입니다.

* https://pypi.org/project/auto-click/
- https://github.com/cord0318/python_auto_click

# 다운로드 📥
**이 모듈은 파이썬 모든 버젼에서 사용 가능합니다.**
윈도우나 리눅스에서 다음과 같이 입력합니다.
```
pip install auto-click
```
오류가 나는 경우, python -m pip install --upgrade pip 로 pip를 업데이트 해주세요.

# 사용법 🤖
```python
from auto import *
auto_click = AutoClick(delay=0.04)
auto_click.run_autoclick()
```

# Update
기능을 더 쉽게 만들었습니다.
cmd 명령어 기능을 만들었습니다.


# Tip
**이제 오토클릭을 cmd에서 사용가능합니다!**
```cmd
auto --help
```
라고 cmd에 쳐보세요!